@@ -4,7 +4,7 @@ use Role::MethodReturns;
 
 
 
-around bootstrap => class_method ( @args ) {
+around bootstrap_tracer => class_method ( @args ) {
     
     returns_object_does_interface( 'OpenTracing::Interface::Tracer' =>
         $original->( $class => @args )
